<?php
namespace tests\Zeedhi\Framework\Controller;

use Zeedhi\Framework\Controller\Metadata as MetadataController;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Routing\Router;
use Zeedhi\Framework\Annotations\Parser;
use Zeedhi\Framework\Cache\Type\MemcachedImpl;
use Zeedhi\Framework\Process\ProcessManagerImpl;
use Zeedhi\Framework\HTTP\Kernel;

class MetadataTest extends \PHPUnit\Framework\TestCase {

    const USER_ID = 'USR_ORG_20';
    private $controller;
    private $metadataSource = './tests/mocks';

    public function setUp() {
        Kernel::$metadataSource = $this->metadataSource;
        $this->controller = new MetadataController(Kernel::$metadataSource);
    }

    public function testBuildOpenAPI(){
        $request = new Request(Router::METHOD_GET, "/generate_openapi", self::USER_ID);
        $response = new Response();
        $this->controller->buildOpenAPI($request, $response);
        $this->assertTrue(file_exists(Kernel::$metadataSource.'/openapi.json'));
    }

    public function testGetOpenAPI(){
        $request = new Request(Router::METHOD_GET, "/openapi", self::USER_ID);
        $response = new Response();
        $this->controller->getOpenAPI($request, $response);
        $metadata = $response->getMetadata();
        $this->assertEquals('description', $metadata['paths']['testing']['description']);
    }

    public function testGetOpenAPIWithResource(){
        $request = new Request(Router::METHOD_GET, "/openapi", self::USER_ID);
        $request->setParameter('resource', 'test');
        $response = new Response();
        $this->controller->getOpenAPI($request, $response);
        $metadata = $response->getMetadata();
        $this->assertEquals('referenceMock', $metadata['$ref']);
    }

    public function testGetMetadata(){
        $request = new Request(Router::METHOD_GET, "/metadata/metadataMock/simpleJSON", self::USER_ID);
        $request->setParameter('fileName', 'metadataMock/simpleJSON');
        $response = new Response();
        $this->controller->getMetadata($request, $response);
        $metadata = $response->getMetadata();
        $this->assertEquals('first', $metadata[0]["name"]);
    }
}